@@ -63,15 +63,13 @@ public:
     void disablehiberanteinitramfs();
     bool processNextPhase();
     void setLocale();
-    void setServices();
+    void setService(const QString &service, bool enabled);
     void writeKeyFile();
 
     bool INSTALL_FROM_ROOT_DEVICE;
     bool POPULATE_MEDIA_MOUNTPOINTS;
 
     QString DEFAULT_HOSTNAME;
-    QString MIN_INSTALL_SIZE;
-    QString PREFERRED_MIN_INSTALL_SIZE;
     QString PROJECTFORUM;
     QString PROJECTNAME;
     QString PROJECTSHORTNAME;
@@ -80,7 +78,7 @@ public:
     QStringList ENABLE_SERVICES;
     bool REMOVE_NOSPLASH;
     QString SQFILE_FULL;
-
+    long long ROOT_BUFFER, HOME_BUFFER;
 
     int showPage(int curr, int next);
     void gotoPage(int next);
@@ -91,45 +89,45 @@ public:
 
 private slots:
     void on_splitter_splitterMoved(int, int);
-    void on_mainTabs_currentChanged(int index);
+    void on_tabsMain_currentChanged(int index);
 
-    void on_abortInstallButton_clicked();
-    void on_backButton_clicked();
-    void on_buttonSetKeyboard_clicked();
-    void on_closeButton_clicked();
-    void on_nextButton_clicked();
-    void on_passwordCheckBox_stateChanged(int);
-    void on_buttonPartReload_clicked();
-    void on_buttonRunParted_clicked();
-    void on_viewServicesButton_clicked();
+    void on_pushAbort_clicked();
+    void on_pushBack_clicked();
+    void on_pushSetKeyboard_clicked();
+    void on_pushClose_clicked();
+    void on_pushNext_clicked();
+    void on_checkShowPass_stateChanged(int);
+    void on_pushPartReload_clicked();
+    void on_pushRunPartMan_clicked();
+    void on_pushServices_clicked();
 
-    void on_diskCombo_currentIndexChanged(int);
+    void on_comboDisk_currentIndexChanged(int);
     void on_sliderPart_sliderPressed();
     void on_sliderPart_valueChanged(int value);
-    void on_checkBoxEncryptAuto_toggled(bool checked);
-    void on_customPartButton_clicked(bool checked);
+    void on_checkEncryptAuto_toggled(bool checked);
+    void on_radioCustomPart_clicked(bool checked);
 
-    void on_buttonBenchmarkFDE_clicked();
-    void on_buttonAdvancedFDE_clicked();
-    void on_buttonAdvancedFDECust_clicked();
-    void on_comboFDEcipher_currentIndexChanged(const QString &arg1);
-    void on_comboFDEchain_currentIndexChanged(const QString &arg1);
-    void on_spinFDEkeysize_valueChanged(int i);
-    void on_comboFDEivgen_currentIndexChanged(const QString &arg1);
+    void on_pushLoadKey_clicked();
+    void on_pushBenchmarkCrypto_clicked();
+    void on_pushAdvancedCrypto_clicked();
+    void on_pushAdvancedCryptoCust_clicked();
+    void on_comboCryptoCipher_currentIndexChanged(const QString &arg1);
+    void on_comboCryptoChain_currentIndexChanged(const QString &arg1);
+    void on_spinCryptoKeySize_valueChanged(int i);
+    void on_comboCryptoIVGen_currentIndexChanged(const QString &arg1);
 
-    void on_grubCheckBox_toggled(bool checked);
-    void on_grubMbrButton_toggled();
-    void on_grubPbrButton_toggled();
-    void on_grubEspButton_toggled();
+    void on_radioBootMBR_toggled();
+    void on_radioBootPBR_toggled();
+    void on_radioBootESP_toggled();
 
-    void on_localeCombo_currentIndexChanged(int index);
-    void on_cmbTimeArea_currentIndexChanged(int index);
+    void on_comboLocale_currentIndexChanged(int index);
+    void on_comboTimeArea_currentIndexChanged(int index);
 
     void on_radioOldHomeUse_toggled(bool);
     void on_radioOldHomeSave_toggled(bool);
     void on_radioOldHomeDelete_toggled(bool);
 
-    void on_progressBar_valueChanged(int value);
+    void on_progInstall_valueChanged(int value);
 
 private:
     MProcess proc;
@@ -168,21 +166,20 @@ private:
     int iLastProgress = -1;
 
     // info needed for Phase 2 of the process
-    bool canMBR, canPBR, canESP;
     bool haveSamba = false;
     bool haveSnapshotUserAccounts = false;
     bool haveOldHome = false;
 
     // Advanced Encryption Settings page
     int ixPageRefAdvancedFDE = 0;
-    int indexFDEcipher;
-    int indexFDEchain;
-    int indexFDEivgen;
-    int indexFDEivhash;
-    int iFDEkeysize;
-    int indexFDEhash;
-    int indexFDErandom;
-    int iFDEroundtime;
+    int indexCryptoCipher;
+    int indexCryptoChain;
+    int indexCryptoIVGen;
+    int indexCryptoIVHash;
+    int iCryptoKeySize;
+    int indexCryptoHash;
+    int indexCryptoRandom;
+    int iCryptoRoundTime;
 
     // cached time zone list
     QStringList listTimeZones;
@@ -197,10 +194,10 @@ private:
     void updatePartitionCombos(QComboBox *changed);
     void setupPartitionSlider();
     void setupAutoMount(bool enabled);
-    bool pretendToInstall(int start, int stop);
+    bool pretendToInstall(int space, long steps);
     bool saveHomeBasic();
-    bool installLinux(const int progend);
-    bool copyLinux(const int progend);
+    bool installLinux();
+    bool copyLinux();
     void failUI(const QString &msg);
     void manageConfig(enum ConfigAction mode);
     void stashServices(bool save);
